@@ -57,12 +57,12 @@
  *     #define SUNDIALS_INT64_T 1
  *     #define SUNDIALS_INT32_T 1
  */
-#define SUNDIALS_INT64_T 1
+#define SUNDIALS_INT32_T 1
 
 /* Define the type of vector indices in SUNDIALS 'sunindextype'.
  * The macro will be defined with a type of the appropriate size.
  */
-#define SUNDIALS_INDEX_TYPE int64_t
+#define SUNDIALS_INDEX_TYPE int32_t
 
 /* Use generic math functions 
  * If it was decided that generic math functions can be used, then
@@ -92,7 +92,7 @@
  * If working libraries for KLU support were found, then
  *     #define SUNDIALS_KLU 
  */
-/* #undef SUNDIALS_KLU */
+#define SUNDIALS_KLU
 
 /* Set if SUNDIALS is built with MPI support.
  * 
